@@ -17,8 +17,12 @@ mod line_desc;
 mod plot;
 mod polynomial;
 mod render;
+mod scatter;
+mod eval;
 
 pub use line_desc::*;
 pub use plot::*;
 pub use polynomial::*;
 pub use render::*;
+pub use scatter::*;
+pub use eval::*;
\ No newline at end of file
