@@ -1,114 +1,14 @@
 use litequad::prelude::*;
 
-use crate::{LineType, Marker, Matrix, Plot};
+use crate::{LineType, Marker, Plot, max_matrix, max_display, get_font_size_y, get_steps, get_font_size_x, divs, sub, count_inv_tens};
 
 const TITLE_SIZE: f32 = 37.;
 const YLABEL_SIZE: f32 = 29.;
 //const XLABEL_SIZE: f32 = 29.;
-const FONT_SIZE: f32 = 24.; //27.
+pub const FONT_SIZE: f32 = 24.; //27.
 const COORD_THICKNESS: f32 = 2.;
 
-pub fn max(arr: &[f64]) -> f64 {
-    let mut max = arr[0];
-    for value in arr {
-        if value > &max {
-            max = *value;
-        }
-    }
-    max
-}
-
-pub fn count_tens(mut num: f64) -> u128 {
-    let mut count = 1;
-    while num > 10. {
-        num /= 10.;
-        count *= 10;
-    }
-    //10u128.pow(count)
-    count
-}
-
-pub fn count_inv_tens(mut num: f64) -> u128 {
-    let mut count = 1;
-    while num.round() == 0. {
-        num *= 10.;
-        count += 1;
-    }
-    10u128.pow(count)
-}
-
-pub fn divs(lhs: &[f64], rhs: f64) -> Vec<f64> {
-    let mut out = Vec::with_capacity(lhs.len());
-    for val in lhs.iter() {
-        out.push(val / rhs);
-    }
-    out
-}
-
-fn get_font_size_x(max: f64) -> f32 {
-    let a = if max >= 3. {
-        count_tens(max) * 10
-    } else {
-        count_inv_tens(max) * 12
-    };
-
-    let a = (a as f64).log10() as f32;
-    FONT_SIZE - (2.9 * a)
-}
-
-fn get_font_size_y(max: f64) -> f32 {
-    let a = if max >= 3. {
-        count_tens(max) * 10
-    } else {
-        count_inv_tens(max) * 1000
-    };
-
-    let a = (a as f64).log10() as f32;
-    FONT_SIZE - (1. * a)
-}
-
-pub fn get_steps(max: f64, mut min_steps: f64) -> f64 {
-    //let mut steps = 4.;
-    if max >= min_steps {
-        while max % min_steps != 0. {
-            min_steps += 1.;
-        }
-        return min_steps;
-    }
-    let max = count_inv_tens(max) as f64 * max * 10.;
-    while max % min_steps != 0. {
-        min_steps -= 1.;
-    }
-    min_steps
-}
-
-fn max_display(max: f64) -> f64 {
-    if max == 0. {
-        return 1.;
-    }
-    if max >= 2. {
-        let tens = count_tens(max);
-        ((max / tens as f64 / 2.).round() * tens as f64) * 2.
-    } else {
-        let tens = count_inv_tens(max);
-        ((max * tens as f64 / 2.).round() / tens as f64) * 2.
-    }
-}
-
-pub fn max_matrix(mat: &Matrix) -> f64 {
-    let mut max = mat[0][0].abs();
-    for x in mat {
-        for x in x {
-            let x = x.abs();
-            if x > max {
-                max = x;
-            }
-        }
-    }
-    max
-}
-
-pub async fn run(plot: Plot) {
+pub async fn run(plot: Plot, min_y: f64) {
     let spacing_x = plot.desc.spacing_x;
     let spacing_y = plot.desc.spacing_y;
 
@@ -126,15 +26,17 @@ pub async fn run(plot: Plot) {
 
     //let maxed = plot.ys.iter().map(|y| y.abs()).collect::<Vec<f64>>();
     //let mut max_y = max(&maxed);
+
     let mut max_y = max_matrix(&plot.ys);
     max_y = max_display(max_y);
 
     let y_font_size = get_font_size_y(max_y);
 
     let steps_y = get_steps(max_y, plot.desc.min_steps_y.into());
-    let step_y = max_y / steps_y;
+    let step_y = (max_y) / steps_y;
 
-    let start_y = step_y;
+    let start_y = if min_y > 0. { min_y } else { step_y };
+    //let start_y = step_y;
 
     loop {
         clear_background(WHITE);
@@ -215,7 +117,11 @@ pub async fn run(plot: Plot) {
 
         for (idx, xs) in plot.xs.iter().enumerate() {
             let xs = divs(xs, step_x);
-            let ys = divs(&plot.ys[idx], step_y);
+
+            let move_up = if min_y > 0. {step_y} else {0.};
+            let ys = sub(&plot.ys[idx], min_y - move_up);
+            let ys = divs(&ys, step_y);
+            
 
             let line_desc = &plot.line_desc[idx];
 
